Struct
QmiMessageWdsGetBindSubscriptionOutput
since: 1.37
Description [src]
struct QmiMessageWdsGetBindSubscriptionOutput {
/* No available fields */
}
The QmiMessageWdsGetBindSubscriptionOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.37
Instance methods
qmi_message_wds_get_bind_subscription_output_get_result
Get the result of the QMI operation.
since: 1.37
qmi_message_wds_get_bind_subscription_output_get_subscription_id
Get the ‘Subscription Id’ field from self.
since: 1.37
qmi_message_wds_get_bind_subscription_output_ref
Atomically increments the reference count of self by one.
since: 1.37
qmi_message_wds_get_bind_subscription_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.37